//----------------------------------------------------------------------------------------
// initial_data_tidal.cpp: Contains initial condition functions for tidal simulations
//----------------------------------------------------------------------------------------

#include <cmath>
#include "initial_data.H"
#include "pde.H"

extern PROBLEM_DESCRIPTION problem_info;     // Storage for problem parameters
#if TURBULENCE_KEY==3  // two equation turbulence models
extern GLS_Data gls_data;                    // Data for two equation turbulence models
#endif



// Initial condition for time-dependent 3D variables
// Parameters: t - time; coord - space coordinates; result - values of time-dependent unknowns
void initial_condition(real t, const real coord[d_space], real result[d_var])
{
  result[U]=result[V]=result[W]=0.;
  // test
//   result[U]=-0.056+0.006*coord[2];
//   result[U]=1.5+0.05*coord[2];
#ifdef BAROCLINIC_KEY
  result[T]=problem_info.T_0;
//   result[T]=13.+0.06*coord[2];
  result[S]=problem_info.S_0;
#endif

#ifdef MASS_CONSERVATION_KEY
  result[TRACER]=0.;
#endif

#if TURBULENCE_KEY>1
  result[K]=7.6e-6;
#if TURBULENCE_KEY==3
  real l=0.1;
  if (problem_info.diff_vert_switch>4)
    result[E]=gls_data.C*std::pow(result[K], real(gls_data.m))*std::pow(l, real(gls_data.n));
#endif
#endif
}

// Initial condition for elevation
// Parameters: t - time; coord - space coordinates; result - values of time-dependent unknowns
void initial_elevation(real t, const real coord[2], real result[])
{
  result[0]=0.;
}
